%bcond_with bootstrap

%global tarball_name RELEASE_%(echo '%{version}' | tr . _)

Name:           cglib
Version:        3.3.0
Release:        %mkrel 5
Group:          Development/Java
Summary:        Code Generation Library for Java
# ASM MethodVisitor is based on ASM code and therefore
# BSD-licensed. Everything else is ASL 2.0.
License:        ASL 2.0 and BSD
URL:            https://github.com/cglib/cglib
BuildArch:      noarch

Source0:        https://github.com/cglib/cglib/archive/%{tarball_name}.tar.gz

Patch0:         0001-Remove-unused-import.patch

%if %{with bootstrap}
BuildRequires:  javapackages-bootstrap
%else
BuildRequires:  maven-local
BuildRequires:  mvn(org.apache.ant:ant)
BuildRequires:  mvn(org.apache.felix:maven-bundle-plugin)
BuildRequires:  mvn(org.ow2.asm:asm)
%endif

%description
cglib is a powerful, high performance and quality code generation library
for Java. It is used to extend Java classes and implements interfaces
at run-time.

%package javadoc
Summary:        Javadoc for %{name}

%description javadoc
Documentation for the cglib code generation library.

%prep
%setup -q -n %{name}-%{tarball_name}
%patch -P 0 -p1

# remove unnecessary dependency on parent POM
%pom_remove_parent

%pom_disable_module cglib-nodep
%pom_disable_module cglib-integration-test
%pom_disable_module cglib-jmh
%pom_xpath_set pom:packaging 'bundle' cglib
%pom_xpath_inject pom:build/pom:plugins '<plugin>
                                           <groupId>org.apache.felix</groupId>
                                           <artifactId>maven-bundle-plugin</artifactId>
                                           <version>1.4.0</version>
                                           <extensions>true</extensions>
                                           <configuration>
                                             <instructions>
                                               <Bundle-SymbolicName>net.sf.cglib.core</Bundle-SymbolicName>
                                               <Export-Package>net.*</Export-Package>
                                               <Import-Package>org.apache.tools.*;resolution:=optional,*</Import-Package>
                                             </instructions>
                                           </configuration>
                                         </plugin>' cglib
%pom_remove_plugin org.apache.maven.plugins:maven-gpg-plugin
%pom_remove_plugin org.apache.maven.plugins:maven-jarsigner-plugin cglib-sample
%pom_remove_plugin -r :maven-javadoc-plugin

%mvn_alias :cglib "net.sf.cglib:cglib" "cglib:cglib-full" "cglib:cglib-nodep" "org.sonatype.sisu.inject:cglib"

%build
# 5 tests fail with OpenJDK 11
# Forwarded upstream: https://github.com/cglib/cglib/issues/119
%mvn_build -f -- -Djava.version.source=1.8 -Djava.version.target=1.8

%install
%mvn_install

%files -f .mfiles
%license LICENSE NOTICE

%files javadoc -f .mfiles-javadoc
%license LICENSE NOTICE




%changelog
* Sun Jun 29 2025 umeabot <umeabot> 3.3.0-5.mga10
+ Revision: 2223290
- Mageia 10 Mass Rebuild

* Thu May 23 2024 ns80 <ns80> 3.3.0-4.mga10
+ Revision: 2066470
- rebuild for java 21

* Mon Jul 25 2022 neoclust <neoclust> 3.3.0-3.mga9
+ Revision: 1871016
- Disable bootstrap

* Sat Jul 23 2022 neoclust <neoclust> 3.3.0-2.mga9
+ Revision: 1870229
- Fix BR for bootstrap

* Tue Jun 07 2022 neoclust <neoclust> 3.3.0-1.mga9
+ Revision: 1863458
- New version 3.3.0
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Fri Sep 11 2020 daviddavid <daviddavid> 3.2.9-3.mga8
+ Revision: 1624394
- Remove unnecessary dependency on parent POM
- Set maven-javadoc-plugin source to 1.8 for Java 11 build
- Ignore 5 test failures from upstream when run on Java 9 or above
- Rebuilt for JDK-11

* Sat Feb 15 2020 umeabot <umeabot> 3.2.9-2.mga8
+ Revision: 1527624
- Mageia 8 Mass Rebuild

* Thu Jul 18 2019 daviddavid <daviddavid> 3.2.9-1.mga8
+ Revision: 1422569
- Update to latest upstream release for ASM 7 support

* Wed Dec 12 2018 daviddavid <daviddavid> 3.2.4-4.mga7
+ Revision: 1340803
- Rebuild to regenerate OSGi manifest after ASM6 upgrade

* Tue Sep 18 2018 umeabot <umeabot> 3.2.4-3.mga7
+ Revision: 1261855
- Mageia 7 Mass Rebuild

* Sun May 14 2017 neoclust <neoclust> 3.2.4-2.mga6
+ Revision: 1101252
- New version 3.2.4

* Wed Mar 02 2016 neoclust <neoclust> 3.1-11.mga6
+ Revision: 981828
- Second rebuild of the java stack

* Mon Feb 22 2016 neoclust <neoclust> 3.1-10.mga6
+ Revision: 976076
- Make ant an optional dependency

* Mon Feb 22 2016 pterjan <pterjan> 3.1-9.mga6
+ Revision: 976071
- Some stuff requires net.sf.cglib:cglib-core

* Sun Feb 21 2016 neoclust <neoclust> 3.1-8.mga6
+ Revision: 975744
- First rebuild of the java stack
- sync package cglib with fedora
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Wed Jan 21 2015 daviddavid <daviddavid> 3.1-4.mga5
+ Revision: 811804
- Sync with fc21

* Wed Oct 15 2014 umeabot <umeabot> 3.1-3.mga5
+ Revision: 741960
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 3.1-2.mga5
+ Revision: 678357
- Mageia 5 Mass Rebuild

* Sun Jun 15 2014 dmorgan <dmorgan> 3.1-1.mga5
+ Revision: 636279
- New version
- New version

* Mon May 05 2014 colin <colin> 2.2-9.mga5
+ Revision: 620207
- Build against objectweb-asm3

* Sat Oct 19 2013 umeabot <umeabot> 2.2-8.mga4
+ Revision: 536475
- Mageia 4 Mass Rebuild

* Mon Sep 23 2013 dmorgan <dmorgan> 2.2-7.mga4
+ Revision: 484332
- Rebuild against nwe javapackages

* Sun Feb 17 2013 dmorgan <dmorgan> 2.2-6.mga3
+ Revision: 398891
- Clean spec file

* Fri Jan 11 2013 umeabot <umeabot> 2.2-5.mga3
+ Revision: 347602
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Nov 16 2011 dmorgan <dmorgan> 2.2-4.mga2
+ Revision: 168035
- Remove dupplicate %%changelog entry ( mga #3356)

* Thu Oct 27 2011 gil <gil> 2.2-3.mga2
+ Revision: 158574
- edit poms

* Wed Oct 19 2011 gil <gil> 2.2-2.mga2
+ Revision: 156593
- edit spec file

* Mon Jan 17 2011 dmorgan <dmorgan> 2.2-2.mga1
+ Revision: 21694
- define _mavenpomdir
- Sync with fedora
- build w/o hook for now
- imported package cglib


* Tue Nov 30 2010 Oden Eriksson <oeriksson@mandriva.com> 0:2.2-2mdv2011.0
+ Revision: 603823
- rebuild

* Sat Nov 07 2009 Frederik Himpe <fhimpe@mandriva.org> 0:2.2-1mdv2010.1
+ Revision: 462314
- update to new version 2.2

* Sun Aug 09 2009 Oden Eriksson <oeriksson@mandriva.com> 0:2.1.3-2.1.7mdv2010.0
+ Revision: 413228
- rebuild

* Fri Mar 06 2009 Antoine Ginies <aginies@mandriva.com> 0:2.1.3-2.1.6mdv2009.1
+ Revision: 350229
- 2009.1 rebuild

* Tue Jan 15 2008 David Walluck <walluck@mandriva.org> 0:2.1.3-2.1.5mdv2008.1
+ Revision: 153457
- remove Requires on java-gcj-compat

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Tue Dec 18 2007 Alexander Kurtakov <akurtakov@mandriva.org> 0:2.1.3-2.1.4mdv2008.1
+ Revision: 132089
- build full cglib

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Sun Dec 16 2007 Anssi Hannula <anssi@mandriva.org> 0:2.1.3-2.1.3mdv2008.1
+ Revision: 120848
- buildrequire java-rpmbuild, i.e. build with icedtea on x86(_64)

* Sat Sep 15 2007 Anssi Hannula <anssi@mandriva.org> 0:2.1.3-2.1.2mdv2008.0
+ Revision: 87271
- rebuild to filter out autorequires of GCJ AOT objects

* Tue Jul 10 2007 David Walluck <walluck@mandriva.org> 0:2.1.3-2.1.1mdv2008.0
+ Revision: 50826
- rebuild


* Sat Dec 16 2006 David Walluck <walluck@mandriva.org> 2.1.3-2.1mdv2007.0
+ Revision: 97994
- Import cglib

* Fri Dec 15 2006 David Walluck <walluck@mandriva.org> 0:2.1.3-2.1mdv2007.1
- release

* Fri Feb 17 2006 Ralph Apel <r.apel at r-apel.de> - 0:2.1.3-2jpp
- Create option --without hook to build without requiring aspectwerkz
- Create new subpackage cglib-nohook containing cglib-nohook.jar
- Main package also provides cglib-nohook
- Add demo subpackage

* Fri Nov 11 2005 Ralph Apel <r.apel at r-apel.de> - 0:2.1.3-1jpp
- Upgrade to 2.1_3
- asm2 is BuildRequired too, because our newer jarjar needs it

* Tue Mar 15 2005 Ralph Apel <r.apel at r-apel.de> - 0:2.1.0-1jpp
- Adapt to upgraded asm 1.5.3 (no src patching required)

* Tue Feb 01 2005 Ralph Apel <r.apel at r-apel.de> - 0:2.0.2-2jpp
- Adapt to upgraded asm 1.4.3 (patch required)

* Thu Sep 09 2004 Ralph Apel <r.apel at r-apel.de> - 0:2.0.2-1jpp
- Upgrade to 2.0.2 (bug fix required)
- Drop cglib-full.jar (identical to cglib.jar in our build)
- Add manual generated offline with "maven xdoc:transform"

* Wed Sep 08 2004 Ralph Apel <r.apel at r-apel.de> - 0:2.0.1-3jpp
- Include cglib-full.jar in package

* Tue Sep 07 2004 Ralph Apel <r.apel at r-apel.de> - 0:2.0.1-2jpp
- Upgrade to Ant 1.6.X
- Build with ant-1.6.2
- Relax some versioned dependencies
- Add missing BuildReq junit
- Upgraded to 2.0.1 and built with aspectwerkz-0.9 on Sat Jun 12 2004 
  by Ralph Apel <r.apel at r-apel.de> as 0:2.0.1-1jpp

* Sat Aug 21 2004 Ralph Apel <r.apel at r-apel.de> - 0:2.0-3jpp
- Build with ant-1.6.2
- Dropped ant from CLASSPATH
- Relaxed jpackage-utils BuildReq

* Wed Jun 02 2004 Randy Watler <rwatler at finali.com> - 0:2.0-2jpp
- Upgrade to Ant 1.6.X

* Sat Feb 28 2004 Ralph Apel <r.apel at r-apel.de> - 0:2.0-1jpp
- First JPackage release

